.. whatprovides documentation master file, created by
   sphinx-quickstart on Thu Jun 25 11:02:20 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to whatprovides's documentation!
========================================

.. include:: introduction.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   examples
   code


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
